NFCISO15693ReaderSession

Struct NFCISO15693ReaderSession 

pub struct NFCISO15693ReaderSession { /* private fields */ }
๐Ÿ‘ŽDeprecated
Reader session for processing ISO15693 tags.

 [NFCReaderSessionDelegate readerSession:didDetectTags:] @link/ will return tag objects that
             are conformed to the NFCISO15693Tag protocol.  This session requires the "com.apple.developer.nfc.readersession.formats" entitlement in your process.

 NOTE:
 Only one NFCReaderSession can be active at any time in the system. Subsequent opened sessions will get queued up and processed by the system in FIFO order.
 The NFCISO15693 tag object returned by this session will only respond to the legacy APIs that are introduced in iOS11.
  

See also Appleโ€™s documentation

Implementations

Source

impl NFCISO15693ReaderSession

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

๐Ÿ‘ŽDeprecated
pub unsafe fn initWithDelegate_queue( this: Allocated<Self>, delegate: &ProtocolObject<dyn NFCReaderSessionDelegate>, queue: Option<&DispatchQueue>, ) -> Retained<Self>

๐Ÿ‘ŽDeprecated: No longer supported
Available on crate feature dispatch2 only.

Parameter delegate: The session will hold a weak ARC reference to this

 NFCReaderSessionDelegate @link/ object.
 @param queue     A dispatch queue where NFCReaderSessionDelegate delegate callbacks will be dispatched to.  A <i>nil</i> value will
                  cause the creation of a serial dispatch queue internally for the session.  The session object will retain the provided dispatch queue.

 @return          A new NFCISO15693ReaderSession instance.
  
Safety

queue possibly has additional threading requirements.

pub unsafe fn restartPolling(&self)

๐Ÿ‘ŽDeprecated: No longer supported

Restart the polling sequence in this session to discover new tags. Tags that are returned previously by

 [NFCReaderSessionDelegate readerSession:didDetectTags:]
             @link/ will become invalid, and all references to these tags shall be removed to properly release the resources.  Calling this method on an invalidated session
             will have no effect; a new reader session is required to restart the reader.
  
Source

impl NFCISO15693ReaderSession

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NFCReaderSession>

pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>

pub unsafe fn sessionQueue(&self) -> Retained<DispatchQueue>

Available on crate feature dispatch2 only.

The NFCReaderSessionDelegate delegate callbacks and the completion block handlers for tag operation will be dispatched on this queue.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesnโ€™t recognize.

See Appleโ€™s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

๐Ÿ‘ŽDeprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable โ€œunder the hoodโ€.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Appleโ€™s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called โ€œlightweight genericsโ€, and thatโ€™s because they arenโ€™t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you donโ€™t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

โ“˜
use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}