NFCNDEFPayload

Struct NFCNDEFPayload 

pub struct NFCNDEFPayload { /* private fields */ }
A NDEF message payload consists of Type Name Format, Type, Payload Identifier, and Payload data. The NDEF payload cannot result into a record that is greater than 128KB in size.

See also Apple’s documentation

Implementations

Source

impl NFCNDEFPayload

pub unsafe fn typeNameFormat(&self) -> NFCTypeNameFormat

pub unsafe fn setTypeNameFormat(&self, type_name_format: NFCTypeNameFormat)

Setter for typeNameFormat.

pub unsafe fn type(&self) -> Retained<NSData>

pub unsafe fn setType(&self, type: &NSData)

Setter for type.

This is copied when set.

pub unsafe fn identifier(&self) -> Retained<NSData>

pub unsafe fn setIdentifier(&self, identifier: &NSData)

Setter for identifier.

This is copied when set.

pub unsafe fn payload(&self) -> Retained<NSData>

pub unsafe fn setPayload(&self, payload: &NSData)

Setter for payload.

This is copied when set.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn initWithFormat_type_identifier_payload( this: Allocated<Self>, format: NFCTypeNameFormat, type: &NSData, identifier: &NSData, payload: &NSData, ) -> Retained<Self>

Parameter format: NFCTypeNameFormat value.

Parameter type: Identifier describing the type of the payload. Empty data indicates field is absent from the payload.

Parameter identifier: Identifier in the form of a URI reference. Empty data indicates field is absent from the payload.

Parameter payload: Payload data. Empty data indicates field is absent from the payload.

This initializer uses the maximum payload chunk size defined by the NFC NDEF specification, i.e. 2^32-1 octets.

pub unsafe fn initWithFormat_type_identifier_payload_chunkSize( this: Allocated<Self>, format: NFCTypeNameFormat, type: &NSData, identifier: &NSData, payload: &NSData, chunk_size: usize, ) -> Retained<Self>

Parameter format: NFCTypeNameFormat value.

Parameter type: Identifier describing the type of the payload. Empty data indicates field is absent from the payload.

Parameter identifier: Identifier in the form of a URI reference. Empty data indicates field is absent from the payload.

Parameter payload: Payload data. Empty data indicates field is absent from the payload.

Parameter chunkSize: Maximum size of a payload chunk. 0 means no chunking on the payload, i.e. payload is fit in a single record.

Source

impl NFCNDEFPayload

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Source

impl NFCNDEFPayload

ConvenienceHelpers.

pub unsafe fn wellKnownTypeURIPayloadWithString( uri: &NSString, ) -> Option<Retained<Self>>

Parameter uri: URI string. UTF-8 encoding representation will be used.

Used for creating NDEF URI payloads which cannot be represented with NSURL object. These are URIs that contain characters such as ‘ä’ and ‘ö’ which cannot be represent by the 7 bits ASCII encoding.

pub unsafe fn wellKnownTypeURIPayloadWithURL( url: &NSURL, ) -> Option<Retained<Self>>

Parameter url: NSURL object.

Preferred convenience function for creating NDEF URI payload with common URLs such as “https://www.apple.com” or “tel:+1-555-555-5555”.

pub unsafe fn wellKnownTypeTextPayloadWithString_locale( text: &NSString, locale: &NSLocale, ) -> Option<Retained<Self>>

Parameter text: Text message.

Parameter locale: NSLocale object. IANA language code specified by the locale will be saved with the payload.

pub unsafe fn wellKnowTypeTextPayloadWithString_locale( text: &NSString, locale: &NSLocale, ) -> Option<Retained<Self>>

👎Deprecated
pub unsafe fn wellKnownTypeURIPayload(&self) -> Option<Retained<NSURL>>

Returns: NSURL object base on a valid Well Known Type URI payload. nil if payload is not a URI.

pub unsafe fn wellKnownTypeTextPayloadWithLocale( &self, locale: &mut Option<Retained<NSLocale>>, ) -> Option<Retained<NSString>>

Parameter locale: Returns NSLocale object that is constructed from the IANA language code stored with the text payload.

Returns: NSString object base on a valid Well Known Type Text payload. nil if payload is not a text.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}