NFCNDEFReaderSession

Struct NFCNDEFReaderSession 

pub struct NFCNDEFReaderSession { /* private fields */ }
NFC reader session for processing NFC Data Exchange Format (NDEF) tags. This session requires the “com.apple.developer.nfc.readersession.formats” entitlement in your process. In addition your application’s Info.plist must contain a non-empty usage description string.

 NFCReaderErrorSecurityViolation @link/ will be returned from @link [NFCNDEFReaderSessionDelegate readerSession:didInvalidateWithError:] @link/
             if the required entitlement is missing when session is started.

 @note       Only one NFCNDEFReaderSession can be active at any time in the system. Subsequent opened sessions will get queued up and processed by the system in FIFO order.
 @note       If the delegate object implements the optional -readerSession:didDetectTags: method the NFCNDEFReaderSession will become a read-write session; see @link
             NFCNDEFReaderSessionDelegate @link/ for detail description.
 @note       The error symbol will not be drawn on the action sheet if -invalidateSessionWithError: method is called on a session that is not a read-write session;
             -invalidateSession: method should be used in a read-only session.
  

See also Apple’s documentation

Implementations

Source

impl NFCNDEFReaderSession

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn initWithDelegate_queue_invalidateAfterFirstRead( this: Allocated<Self>, delegate: &ProtocolObject<dyn NFCNDEFReaderSessionDelegate>, queue: Option<&DispatchQueue>, invalidate_after_first_read: bool, ) -> Retained<Self>

Available on crate feature dispatch2 only.

Parameter delegate: The session will hold a weak ARC reference to this

 NFCNDEFReaderSessionDelegate @link/ object.
 @param queue     A dispatch queue where NFCNDEFReaderSessionDelegate delegate callbacks will be dispatched to.  A <i>nil</i> value will
                  cause the creation of a serial dispatch queue internally for the session.  The session object will retain the provided dispatch queue.
 @param invalidateAfterFirstRead  Session will automatically invalidate after the first NDEF tag is read successfully when this is set to YES, and
                                  -readerSession:didInvalidateWithError: will return NFCReaderSessionInvalidationErrorFirstNDEFTagRead in this case.
                                  Set to NO if the delegate object implements the -readerSession:didDetectTags: optional method.

 @return          A new NFCNDEFReaderSession instance.

 @discussion      A NDEF reader session will scan and detect NFC Forum tags that contain a valid NDEF message.  NFC Forum Tag type 1 to 5 that
                  is NDEF formatted are supported.  A modal system UI will present once -beginSession is called to inform the start of the session; the UI sheet
                  is automatically dismissed when the session is invalidated either by the user or by calling -invalidateSession.  The alertMessage property shall be set
                  prior to -beginSession to display a message on the action sheet UI for the tag scanning operation.

                  The reader session has the following properties:
                  + An opened session has a 60 seconds time limit restriction after -beginSession is called; -readerSession:didInvalidateWithError: will return
                  NFCReaderSessionInvalidationErrorSessionTimeout error when the time limit is reached.
                  + Only 1 active reader session is allowed in the system; -readerSession:didInvalidateWithError: will return NFCReaderSessionInvalidationErrorSystemIsBusy
                  when a new reader session is initiated by -beginSession when there is an active reader session.  
                  + -readerSession:didInvalidateWithError: will return NFCReaderSessionInvalidationErrorUserCanceled when user clicks on the done button on the UI.
                  + -readerSession:didInvalidateWithError: will return NFCReaderSessionInvalidationErrorSessionTerminatedUnexpectedly when the client application enters
                  the background state.
                  + -readerSession:didInvalidateWithError: will return NFCReaderErrorUnsupportedFeature when 1) reader mode feature is not available on the hardware,
                  2) client application does not have the required entitlement.

                  The session's mode of operation is determined by the implementation of the delegate object.  The -readerSession:didDetectTags: optional method will
                  enable the read-write capability and suppress the -readerSession:didDetectNDEFs: callback for the session.
  
Safety

queue possibly has additional threading requirements.

pub unsafe fn restartPolling(&self)

Restart the polling sequence in this session to discover new NDEF tags. New tags discovered from polling will return in the subsequent

 [NFCNDEFReaderSessionDelegate readerSession:didDetectTags:]
             @link/ call.  Tags that are returned previously by @link [NFCNDEFReaderSessionDelegate -readerSession:didDetectTags:] @link/ will become invalid,
             and all references to these tags shall be removed to properly release the resources.  Calling this method on an invalidated session
             will have no effect; a new reader session is required to restart the reader. Calling this method on an instance initiated with a delegate object that does not implement
             the optional -readerSession:didDetectTags: method has no effect as RF polling restart is done automatically.
  
pub unsafe fn connectToTag_completionHandler( &self, tag: &ProtocolObject<dyn NFCNDEFTag>, completion_handler: &DynBlock<dyn Fn(*mut NSError)>, )

Available on crate feature block2 only.

Parameter tag: A NFCTag protocol compliant tag object that will be connect to.

Parameter completionHandler: Completion handler called when the operation is completed. error is nil if operation succeeds. A

 NFCErrorDomain @link/ error is returned when there is a communication issue with the tag.

 @discussion  This method establishes a tag connection and activates the tag.  Connecting to the same tag that is currently opened has no effect.
              Connecting to a different tag will automatically terminate the previous tag connection and put it into the halt state.  Tag stays in the
              connected state until another tag is connected or the polling is restarted.
  
Source

impl NFCNDEFReaderSession

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Methods from Deref<Target = NFCReaderSession>

pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>

pub unsafe fn sessionQueue(&self) -> Retained<DispatchQueue>

Available on crate feature dispatch2 only.

The NFCReaderSessionDelegate delegate callbacks and the completion block handlers for tag operation will be dispatched on this queue.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}