pub struct NFCVASReaderSession { /* private fields */ }Expand description
Reader session for processing Value Added Service (VAS) tags. This session requires the “com.apple.developer.nfc.readersession.formats” entitlement in your process. In addition your application’s Info.plist must contain a non-empty usage description string.
NFCReaderErrorSecurityViolation @link/ will be returned from @link [NFCVASReaderSessionDelegate readerSession:didInvalidateWithError:] @link/
if the required entitlement is missing when session is started.
NOTE:
Only one NFCReaderSession can be active at any time in the system. Subsequent opened sessions will get queued up and processed by the system in FIFO order.
See also Apple’s documentation
Implementations
Sourceimpl NFCVASReaderSession
impl NFCVASReaderSession
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn initWithVASCommandConfigurations_delegate_queue(
this: Allocated<Self>,
command_configurations: &NSArray<NFCVASCommandConfiguration>,
delegate: &ProtocolObject<dyn NFCVASReaderSessionDelegate>,
queue: Option<&DispatchQueue>,
) -> Retained<Self>
Available on crate feature dispatch2 only.
pub unsafe fn initWithVASCommandConfigurations_delegate_queue( this: Allocated<Self>, command_configurations: &NSArray<NFCVASCommandConfiguration>, delegate: &ProtocolObject<dyn NFCVASReaderSessionDelegate>, queue: Option<&DispatchQueue>, ) -> Retained<Self>
dispatch2 only.Parameter commandConfigurations: NSArray of NFCVASCommandConfiguration objects. Each NFCVASCommandConfiguration defines one GET VAS DATA command send to
a compatible tag when discovered. The order of elements in the array defines the order of the command execution.
Parameter delegate: The session will hold a weak ARC reference to this
NFCVASReaderSessionDelegate @link/ object.
@param queue A dispatch queue where NFCVASReaderSessionDelegate delegate callbacks will be dispatched to. A <i>nil</i> value will
cause the creation of a serial dispatch queue internally for the session. The session object will retain the provided dispatch queue.
@return A new NFCVASReaderSession instance.
@discussion A VAS reader session will automatically scan and detect tag that is compatible with the VAS protocol. The session will advertise as a
VAS App Only terminal. A modal system UI will present once -beginSession is called to inform the start of the session; the UI sheet
is automatically dismissed when the session is invalidated either by the user or by calling -invalidateSession. The alertMessage property shall be set
prior to -beginSession to display a message on the action sheet UI for the tag scanning operation.
The reader session has the following properties:
+ An opened session has a 60 seconds time limit restriction after -beginSession is called; -readerSession:didInvalidateWithError: will return
NFCReaderSessionInvalidationErrorSessionTimeout error when the time limit is reached.
+ Only 1 active reader session is allowed in the system; -readerSession:didInvalidateWithError: will return NFCReaderSessionInvalidationErrorSystemIsBusy
when a new reader session is initiated by -beginSession when there is an active reader session.
+ -readerSession:didInvalidateWithError: will return NFCReaderSessionInvalidationErrorUserCanceled when user clicks on the done button on the UI.
+ -readerSession:didInvalidateWithError: will return NFCReaderSessionInvalidationErrorSessionTerminatedUnexpectedly when the client application enters
the background state.
+ -readerSession:didInvalidateWithError: will return NFCReaderErrorUnsupportedFeature when 1) reader mode feature is not available on the hardware,
2) client application does not have the required entitlement.
Safety
queue possibly has additional threading requirements.
Methods from Deref<Target = NFCReaderSession>
pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>
Sourcepub unsafe fn sessionQueue(&self) -> Retained<DispatchQueue>
Available on crate feature dispatch2 only.
pub unsafe fn sessionQueue(&self) -> Retained<DispatchQueue>
dispatch2 only.The NFCReaderSessionDelegate delegate callbacks and the completion block handlers for tag operation will be dispatched on this queue.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for NFCVASReaderSession
impl AsRef<AnyObject> for NFCVASReaderSession
Sourceimpl AsRef<NFCReaderSession> for NFCVASReaderSession
impl AsRef<NFCReaderSession> for NFCVASReaderSession
Sourcefn as_ref(&self) -> &NFCReaderSession
fn as_ref(&self) -> &NFCReaderSession
Sourceimpl AsRef<NSObject> for NFCVASReaderSession
impl AsRef<NSObject> for NFCVASReaderSession
Sourceimpl Borrow<AnyObject> for NFCVASReaderSession
impl Borrow<AnyObject> for NFCVASReaderSession
Sourceimpl Borrow<NFCReaderSession> for NFCVASReaderSession
impl Borrow<NFCReaderSession> for NFCVASReaderSession
Sourcefn borrow(&self) -> &NFCReaderSession
fn borrow(&self) -> &NFCReaderSession
Sourceimpl Borrow<NSObject> for NFCVASReaderSession
impl Borrow<NSObject> for NFCVASReaderSession
Sourceimpl ClassType for NFCVASReaderSession
impl ClassType for NFCVASReaderSession
Sourceconst NAME: &'static str = "NFCVASReaderSession"
const NAME: &'static str = "NFCVASReaderSession"
Sourcetype Super = NFCReaderSession
type Super = NFCReaderSession
Sourcetype ThreadKind = <<NFCVASReaderSession as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<NFCVASReaderSession as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for NFCVASReaderSession
impl Debug for NFCVASReaderSession
Sourceimpl Deref for NFCVASReaderSession
impl Deref for NFCVASReaderSession
Sourceimpl Hash for NFCVASReaderSession
impl Hash for NFCVASReaderSession
Sourceimpl Message for NFCVASReaderSession
impl Message for NFCVASReaderSession
Sourceimpl NFCReaderSessionProtocol for NFCVASReaderSession
impl NFCReaderSessionProtocol for NFCVASReaderSession
Sourceunsafe fn isReady(&self) -> bool
unsafe fn isReady(&self) -> bool
Sourceunsafe fn alertMessage(&self) -> Retained<NSString>
unsafe fn alertMessage(&self) -> Retained<NSString>
Sourceunsafe fn setAlertMessage(&self, alert_message: &NSString)
unsafe fn setAlertMessage(&self, alert_message: &NSString)
alertMessage. Read moreSourceunsafe fn invalidateSession(&self)
unsafe fn invalidateSession(&self)
Sourceunsafe fn invalidateSessionWithErrorMessage(&self, error_message: &NSString)
unsafe fn invalidateSessionWithErrorMessage(&self, error_message: &NSString)
Sourceimpl NSObjectProtocol for NFCVASReaderSession
impl NSObjectProtocol for NFCVASReaderSession
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref