pub struct NFCISO15693CustomCommandConfiguration { /* private fields */ }Expand description
Configuration options for the Manufacturer Custom command.
See also Apple’s documentation
Implementations
Sourceimpl NFCISO15693CustomCommandConfiguration
impl NFCISO15693CustomCommandConfiguration
Sourcepub unsafe fn manufacturerCode(&self) -> NSUInteger
pub unsafe fn manufacturerCode(&self) -> NSUInteger
Manufacturer code. Valid range is 0x00 to 0xFF.
Sourcepub unsafe fn setManufacturerCode(&self, manufacturer_code: NSUInteger)
pub unsafe fn setManufacturerCode(&self, manufacturer_code: NSUInteger)
Setter for manufacturerCode.
Sourcepub unsafe fn customCommandCode(&self) -> NSUInteger
pub unsafe fn customCommandCode(&self) -> NSUInteger
Manufacturer Custom Command Index. Valid range is 0xA0 to 0xDF.
Sourcepub unsafe fn setCustomCommandCode(&self, custom_command_code: NSUInteger)
pub unsafe fn setCustomCommandCode(&self, custom_command_code: NSUInteger)
Setter for customCommandCode.
Sourcepub unsafe fn requestParameters(&self) -> Retained<NSData>
pub unsafe fn requestParameters(&self) -> Retained<NSData>
Custom request data.
Sourcepub unsafe fn setRequestParameters(&self, request_parameters: &NSData)
pub unsafe fn setRequestParameters(&self, request_parameters: &NSData)
Setter for requestParameters.
This is copied when set.
Sourcepub unsafe fn initWithManufacturerCode_customCommandCode_requestParameters(
this: Allocated<Self>,
manufacturer_code: NSUInteger,
custom_command_code: NSUInteger,
request_parameters: Option<&NSData>,
) -> Retained<Self>
pub unsafe fn initWithManufacturerCode_customCommandCode_requestParameters( this: Allocated<Self>, manufacturer_code: NSUInteger, custom_command_code: NSUInteger, request_parameters: Option<&NSData>, ) -> Retained<Self>
Parameter manufacturerCode: 8 bits manufacturer code.
Parameter customCommandCode: 8 bits custom command code. Valid range is 0xA0 to 0xDF.
Parameter requestParameters: Optional custom request parameters.
Initialize with default zero maximum retry and zero retry interval.
Sourcepub unsafe fn initWithManufacturerCode_customCommandCode_requestParameters_maximumRetries_retryInterval(
this: Allocated<Self>,
manufacturer_code: NSUInteger,
custom_command_code: NSUInteger,
request_parameters: Option<&NSData>,
maximum_retries: NSUInteger,
retry_interval: NSTimeInterval,
) -> Retained<Self>
pub unsafe fn initWithManufacturerCode_customCommandCode_requestParameters_maximumRetries_retryInterval( this: Allocated<Self>, manufacturer_code: NSUInteger, custom_command_code: NSUInteger, request_parameters: Option<&NSData>, maximum_retries: NSUInteger, retry_interval: NSTimeInterval, ) -> Retained<Self>
Parameter manufacturerCode: 8 bits manufacturer code.
Parameter customCommandCode: 8 bits custom command code. Valid range is 0xA0 to 0xDF.
Parameter requestParameters: Optional custom request parameters.
Parameter maximumRetries: Maximum number of retry attempt when tag response is not received.
Parameter retryInterval: Time interval wait between each retry attempt.
Methods from Deref<Target = NFCTagCommandConfiguration>
Sourcepub unsafe fn maximumRetries(&self) -> NSUInteger
pub unsafe fn maximumRetries(&self) -> NSUInteger
Maximum number of retries. Valid value is 0 to 256. Default is 0.
Sourcepub unsafe fn setMaximumRetries(&self, maximum_retries: NSUInteger)
pub unsafe fn setMaximumRetries(&self, maximum_retries: NSUInteger)
Setter for maximumRetries.
Sourcepub unsafe fn retryInterval(&self) -> NSTimeInterval
pub unsafe fn retryInterval(&self) -> NSTimeInterval
Delay in seconds before retry occurs. Default is 0.
Sourcepub unsafe fn setRetryInterval(&self, retry_interval: NSTimeInterval)
pub unsafe fn setRetryInterval(&self, retry_interval: NSTimeInterval)
Setter for retryInterval.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<NFCTagCommandConfiguration> for NFCISO15693CustomCommandConfiguration
impl AsRef<NFCTagCommandConfiguration> for NFCISO15693CustomCommandConfiguration
Sourcefn as_ref(&self) -> &NFCTagCommandConfiguration
fn as_ref(&self) -> &NFCTagCommandConfiguration
Sourceimpl Borrow<NFCTagCommandConfiguration> for NFCISO15693CustomCommandConfiguration
impl Borrow<NFCTagCommandConfiguration> for NFCISO15693CustomCommandConfiguration
Sourcefn borrow(&self) -> &NFCTagCommandConfiguration
fn borrow(&self) -> &NFCTagCommandConfiguration
Sourceimpl ClassType for NFCISO15693CustomCommandConfiguration
impl ClassType for NFCISO15693CustomCommandConfiguration
Sourceconst NAME: &'static str = "NFCISO15693CustomCommandConfiguration"
const NAME: &'static str = "NFCISO15693CustomCommandConfiguration"
Sourcetype Super = NFCTagCommandConfiguration
type Super = NFCTagCommandConfiguration
Sourcetype ThreadKind = <<NFCISO15693CustomCommandConfiguration as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<NFCISO15693CustomCommandConfiguration as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for NFCISO15693CustomCommandConfiguration
impl CopyingHelper for NFCISO15693CustomCommandConfiguration
Sourcetype Result = NFCISO15693CustomCommandConfiguration
type Result = NFCISO15693CustomCommandConfiguration
Self if the type has no
immutable counterpart. Read moreSourceimpl NSCopying for NFCISO15693CustomCommandConfiguration
impl NSCopying for NFCISO15693CustomCommandConfiguration
Sourceimpl NSObjectProtocol for NFCISO15693CustomCommandConfiguration
impl NSObjectProtocol for NFCISO15693CustomCommandConfiguration
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref