pub struct NFCISO15693ReaderSession { /* private fields */ }Expand description
Reader session for processing ISO15693 tags.
[NFCReaderSessionDelegate readerSession:didDetectTags:] @link/ will return tag objects that
are conformed to the NFCISO15693Tag protocol. This session requires the "com.apple.developer.nfc.readersession.formats" entitlement in your process.
NOTE:
Only one NFCReaderSession can be active at any time in the system. Subsequent opened sessions will get queued up and processed by the system in FIFO order.
The NFCISO15693 tag object returned by this session will only respond to the legacy APIs that are introduced in iOS11.
See also Appleโs documentation
Implementations
Sourceimpl NFCISO15693ReaderSession
impl NFCISO15693ReaderSession
pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>
Sourcepub unsafe fn initWithDelegate_queue(
this: Allocated<Self>,
delegate: &ProtocolObject<dyn NFCReaderSessionDelegate>,
queue: Option<&DispatchQueue>,
) -> Retained<Self>
๐Deprecated: No longer supportedAvailable on crate feature dispatch2 only.
pub unsafe fn initWithDelegate_queue( this: Allocated<Self>, delegate: &ProtocolObject<dyn NFCReaderSessionDelegate>, queue: Option<&DispatchQueue>, ) -> Retained<Self>
dispatch2 only.Parameter delegate: The session will hold a weak ARC reference to this
NFCReaderSessionDelegate @link/ object.
@param queue A dispatch queue where NFCReaderSessionDelegate delegate callbacks will be dispatched to. A <i>nil</i> value will
cause the creation of a serial dispatch queue internally for the session. The session object will retain the provided dispatch queue.
@return A new NFCISO15693ReaderSession instance.
Safety
queue possibly has additional threading requirements.
Sourcepub unsafe fn restartPolling(&self)
๐Deprecated: No longer supported
pub unsafe fn restartPolling(&self)
Restart the polling sequence in this session to discover new tags. Tags that are returned previously by
[NFCReaderSessionDelegate readerSession:didDetectTags:]
@link/ will become invalid, and all references to these tags shall be removed to properly release the resources. Calling this method on an invalidated session
will have no effect; a new reader session is required to restart the reader.
Methods from Deref<Target = NFCReaderSession>
pub unsafe fn delegate(&self) -> Option<Retained<AnyObject>>
Sourcepub unsafe fn sessionQueue(&self) -> Retained<DispatchQueue>
Available on crate feature dispatch2 only.
pub unsafe fn sessionQueue(&self) -> Retained<DispatchQueue>
dispatch2 only.The NFCReaderSessionDelegate delegate callbacks and the completion block handlers for tag operation will be dispatched on this queue.
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesnโt recognize.
See Appleโs documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
๐Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable โunder the hoodโ.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Appleโs documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called โlightweight genericsโ, and thatโs because they arenโt exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you donโt need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for NFCISO15693ReaderSession
impl AsRef<AnyObject> for NFCISO15693ReaderSession
Sourceimpl AsRef<NFCReaderSession> for NFCISO15693ReaderSession
impl AsRef<NFCReaderSession> for NFCISO15693ReaderSession
Sourcefn as_ref(&self) -> &NFCReaderSession
fn as_ref(&self) -> &NFCReaderSession
Sourceimpl AsRef<NSObject> for NFCISO15693ReaderSession
impl AsRef<NSObject> for NFCISO15693ReaderSession
Sourceimpl Borrow<AnyObject> for NFCISO15693ReaderSession
impl Borrow<AnyObject> for NFCISO15693ReaderSession
Sourceimpl Borrow<NFCReaderSession> for NFCISO15693ReaderSession
impl Borrow<NFCReaderSession> for NFCISO15693ReaderSession
Sourcefn borrow(&self) -> &NFCReaderSession
fn borrow(&self) -> &NFCReaderSession
Sourceimpl Borrow<NSObject> for NFCISO15693ReaderSession
impl Borrow<NSObject> for NFCISO15693ReaderSession
Sourceimpl ClassType for NFCISO15693ReaderSession
impl ClassType for NFCISO15693ReaderSession
Sourceconst NAME: &'static str = "NFCISO15693ReaderSession"
const NAME: &'static str = "NFCISO15693ReaderSession"
Sourcetype Super = NFCReaderSession
type Super = NFCReaderSession
Sourcetype ThreadKind = <<NFCISO15693ReaderSession as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<NFCISO15693ReaderSession as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl Debug for NFCISO15693ReaderSession
impl Debug for NFCISO15693ReaderSession
Sourceimpl Deref for NFCISO15693ReaderSession
impl Deref for NFCISO15693ReaderSession
Sourceimpl Hash for NFCISO15693ReaderSession
impl Hash for NFCISO15693ReaderSession
Sourceimpl Message for NFCISO15693ReaderSession
impl Message for NFCISO15693ReaderSession
Sourceimpl NFCReaderSessionProtocol for NFCISO15693ReaderSession
impl NFCReaderSessionProtocol for NFCISO15693ReaderSession
Sourceunsafe fn isReady(&self) -> bool
unsafe fn isReady(&self) -> bool
Sourceunsafe fn alertMessage(&self) -> Retained<NSString>
unsafe fn alertMessage(&self) -> Retained<NSString>
Sourceunsafe fn setAlertMessage(&self, alert_message: &NSString)
unsafe fn setAlertMessage(&self, alert_message: &NSString)
alertMessage. Read moreSourceunsafe fn invalidateSession(&self)
unsafe fn invalidateSession(&self)
Sourceunsafe fn invalidateSessionWithErrorMessage(&self, error_message: &NSString)
unsafe fn invalidateSessionWithErrorMessage(&self, error_message: &NSString)
Sourceimpl NSObjectProtocol for NFCISO15693ReaderSession
impl NSObjectProtocol for NFCISO15693ReaderSession
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref